==> extension_opencv-4.11.0.tar.xz: extension_opencv-4.11.0/config.sh <==
echo "# $EXTENSION/build_order.txt" 				 	 > $EXTENSION/build_order.txt
echo "# <scriptname> (without .sh)" 					>> $EXTENSION/build_order.txt
echo "" 												>> $EXTENSION/build_order.txt
	
# Required
[[ $(command -v cmake) == "" ]] && echo "Installing cmake" && extension --install cmake && echo "Finished cmake"
[[ $(command -v bsdunzip) == "" ]] && echo "Installing libarchive" && extension --install libarchive && echo "Finished libarchive"
# Recommended
if [[ $INSTALL_RECOMMENDED != false ]]; then 
	[[ $(command -v ffmpeg) == "" ]] && echo "Installing ffmpeg" && extension --install ffmpeg && echo "Finished ffmpeg"
	[[ $(command -v gst-play-1.0) == "" ]] && echo "Installing gst_plugins_base" && extension --install gst_plugins_base && echo "Finished gst_plugins_base"
	[[ $(command -v gtk-launch) == "" ]] && echo "Installing gtk3" && extension --install gtk3 && echo "Finished gtk3"
	[[ $(command -v jasper) == "" ]] && echo "Installing jasper" && extension --install jasper && echo "Finished jasper"
	#[ ! -f /lib/libexif.so ] && echo "Installing libexif" && extension --install libexif && echo "Finished libexif"
	[[ $(command -v cjpeg) == "" ]] && echo "Installing libjpeg_turbo" && extension --install libjpeg_turbo && echo "Finished libjpeg_turbo"
	[[ $(command -v pngfix) == "" ]] && echo "Installing libpng" && extension --install libpng && echo "Finished libpng"
	[[ $(command -v tiffinfo) == "" ]] && echo "Installing libtiff" && extension --install libtiff && echo "Finished libtiff"
	[[ $(command -v webpinfo) == "" ]] && echo "Installing libwebp" && extension --install libwebp && echo "Finished libwebp"
	[[ $(command -v opj_dump) == "" ]] && echo "Installing openjpeg" && extension --install openjpeg && echo "Finished openjpeg"
	[[ $(command -v v4l2gl) == "" ]] && echo "Installing v4l_utils" && extension --install v4l_utils && echo "Finished v4l_utils"
	#[[ $(command -v xine-config) == "" ]] && echo "Installing xine_lib" && extension --install xine_lib && echo "Finished xine_lib"
	# Recommended
	[[ $(command -v ant) == "" ]] && echo "Installing apache_ant" && extension --install apache_ant && echo "Finished apache_ant"
	[[ $(command -v doxygen) == "" ]] && echo "Installing doxygen" && extension --install doxygen && echo "Finished doxygen"
	[[ $(command -v jar) == "" ]] && echo "Installing openjdk" && extension --install openjdk && echo "Finished openjdk"
	[[ $(command -v f2py) == "" ]] && echo "Installing py_numpy" && extension --install py_numpy && echo "Finished py_numpy"
	[[ $(command -v protoc) == "" ]] && echo "Installing protobuf" && extension --install protobuf && echo "Finished protobuf"
fi

if [ $BUILD_ALL == "false" ] && [[ $(command -v opencv_version) == "" ]]; then
	echo "opencv" 										>> $EXTENSION/build_order.txt
fi
if [ $BUILD_ALL == "true" ]; then
	echo "opencv" 										>> $EXTENSION/build_order.txt
fi
echo "complete _" 										>> $EXTENSION/build_order.txt

==> extension_opencv-4.12.0.tar.xz: extension_opencv-4.12.0/config.sh <==
echo "# $EXTENSION/build_order.txt" 				 	 > $EXTENSION/build_order.txt
echo "# <scriptname> (without .sh)" 					>> $EXTENSION/build_order.txt
echo "" 												>> $EXTENSION/build_order.txt
	
# Required
[[ $(command -v cmake) == "" ]] && echo "Installing cmake" && extension --install cmake && echo "Finished cmake"
[[ $(command -v bsdunzip) == "" ]] && echo "Installing libarchive" && extension --install libarchive && echo "Finished libarchive"
# Recommended
if [[ $INSTALL_RECOMMENDED != false ]]; then 
	[[ $(command -v ffmpeg) == "" ]] && echo "Installing ffmpeg" && extension --install ffmpeg && echo "Finished ffmpeg"
	[[ $(command -v gst-play-1.0) == "" ]] && echo "Installing gst_plugins_base" && extension --install gst_plugins_base && echo "Finished gst_plugins_base"
	[[ $(command -v gtk-launch) == "" ]] && echo "Installing gtk3" && extension --install gtk3 && echo "Finished gtk3"
	[[ $(command -v jasper) == "" ]] && echo "Installing jasper" && extension --install jasper && echo "Finished jasper"
	[ ! -f /lib/libexif.so ] && echo "Installing libexif" && extension --install libexif && echo "Finished libexif"
	[[ $(command -v cjpeg) == "" ]] && echo "Installing libjpeg_turbo" && extension --install libjpeg_turbo && echo "Finished libjpeg_turbo"
	[[ $(command -v pngfix) == "" ]] && echo "Installing libpng" && extension --install libpng && echo "Finished libpng"
	[[ $(command -v tiffinfo) == "" ]] && echo "Installing libtiff" && extension --install libtiff && echo "Finished libtiff"
	[[ $(command -v webpinfo) == "" ]] && echo "Installing libwebp" && extension --install libwebp && echo "Finished libwebp"
	[[ $(command -v opj_dump) == "" ]] && echo "Installing openjpeg" && extension --install openjpeg && echo "Finished openjpeg"
	[[ $(command -v v4l2gl) == "" ]] && echo "Installing v4l_utils" && extension --install v4l_utils && echo "Finished v4l_utils"
	[[ $(command -v xine-config) == "" ]] && echo "Installing xine_lib" && extension --install xine_lib && echo "Finished xine_lib"
	# Recommended
	[[ $(command -v ant) == "" ]] && echo "Installing apache_ant" && extension --install apache_ant && echo "Finished apache_ant"
	[[ $(command -v doxygen) == "" ]] && echo "Installing doxygen" && extension --install doxygen && echo "Finished doxygen"
	[[ $(command -v jar) == "" ]] && echo "Installing openjdk" && extension --install openjdk && echo "Finished openjdk"
	[[ $(command -v f2py) == "" ]] && echo "Installing py_numpy" && extension --install py_numpy && echo "Finished py_numpy"
	[[ $(command -v protoc) == "" ]] && echo "Installing protobuf" && extension --install protobuf && echo "Finished protobuf"
fi

if [ $BUILD_ALL == "false" ] && [[ $(command -v opencv_version) == "" ]]; then
	echo "opencv" 										>> $EXTENSION/build_order.txt
fi
if [ $BUILD_ALL == "true" ]; then
	echo "opencv" 										>> $EXTENSION/build_order.txt
fi
echo "complete _" 										>> $EXTENSION/build_order.txt
